@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*-
-"""Axonius API Client package."""
-from __future__ import absolute_import, division, print_function, unicode_literals
-
+"""Python API Client for Axonius."""
 from . import api, auth, cli, constants, exceptions, http, logs, tools, version
-from .api import Adapters, Devices, Enforcements, Users
+from .api import Adapters, Devices, Enforcements, System, Users
 from .auth import ApiKey
 from .connect import Connect
 from .http import Http
@@ -23,6 +21,7 @@ __all__ = (
     "Devices",
     "Adapters",
     "Enforcements",
+    "System",
     # modules
     "api",
     "auth",
