@@ -3,7 +3,7 @@
 import click
 
 from ..context import AliasedGroup
-from . import cmd_shell, cmd_write_config
+from . import cmd_shell, cmd_sysinfo, cmd_write_config
 
 
 @click.group(cls=AliasedGroup)
@@ -13,3 +13,4 @@ def tools():
 
 tools.add_command(cmd_shell.cmd)
 tools.add_command(cmd_write_config.cmd)
+tools.add_command(cmd_sysinfo.cmd)
